@@ -3,9 +3,6 @@ package Perlanet::Trait::YAMLConfig;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose::Role;
 use namespace::autoclean;
 
@@ -61,56 +58,34 @@ configuration file.
 
 =head1 METHODS
 
-=head2 THIRTY_DAYS
-
-The default length of caching, if caching options are present in the
-configuration
-
 =head2 get_config_from_file
 
 Extracts the configuration from a YAML file
 
 =cut
 
-with 'MooseX::ConfigFromFile';
+with 'MooseX::ConfigFromFile', 'Perlanet::Role::Config';
 
 use Carp qw( carp croak );
 use YAML qw( LoadFile );
 
-use constant THIRTY_DAYS => 30 * 24 * 60 * 60;
-
 sub get_config_from_file {
-  my ($self, $file) = @_;
+  my $class = shift;
+  return $class->get_config(config_file => $_[0]);
+}
 
-  open my $cfg_file, '<:utf8', $file
+sub read_config {
+  my $class = shift;
+  my (%params) = @_;
+
+  my $file = $params{config_file}
+    // croak "No config file passed to read_config().";
+
+  open my $cfg_file, '<:encoding(UTF-8)', $file
     or croak "Cannot open file $file: $!";
 
   my $cfg = LoadFile($cfg_file);
 
-  $cfg->{feeds} = [ map {
-    Perlanet::Feed->new($_)
-  } @{ $cfg->{feeds} } ];
-
-  $cfg->{max_entries} = $cfg->{entries}
-    if $cfg->{entries};
-
-  if ($cfg->{cache_dir}) {
-    eval { require CHI; };
-
-    if ($@) {
-      carp "You need to install CHI to enable caching.\n";
-      carp "Caching disabled for this run.\n";
-      delete $cfg->{cache_dir};
-    }
-  }
-
-  $cfg->{cache_dir}
-    and $cfg->{cache} = CHI->new(
-      driver     => 'File',
-      root_dir   => delete $cfg->{cache_dir},
-      expires_in => THIRTY_DAYS,
-    );
-
   return $cfg;
 }
 
